@@ -1,20 +1,12 @@
-from typing import (
-    List,
-    Iterable,
-    Tuple,
-    Optional,
-    TypeVar,
-    Type,
-    Dict,
-    Coroutine,
-    Generator,
-    Callable,
-)
-import os
 import asyncio
-from dataclasses import dataclass
+import os
 from contextlib import contextmanager
+from dataclasses import dataclass
+from typing import Any, Callable, Coroutine, Dict, Generator, Iterable, List, Optional
+from typing import Tuple, Type, TypeVar
+
 import urwid
+from dbus_next.message_bus import BaseMessageBus
 
 from ovshell import api
 
@@ -85,6 +77,7 @@ class ScreenManagerStub(api.ScreenManager):
     _tasks: List[Tuple[api.Activity, asyncio.Task]]
     _dialog: Optional[DialogStub]
     _indicators: Dict[str, TopIndicatorStub]
+    _status: Optional[api.UrwidText]
 
     def __init__(self, log: List[str]) -> None:
         self._log = log
@@ -92,6 +85,7 @@ class ScreenManagerStub(api.ScreenManager):
         self._tasks = []
         self._dialog = None
         self._indicators = {}
+        self._status = None
 
     def draw(self) -> None:
         self._log.append("Screen redrawn")
@@ -102,6 +96,11 @@ class ScreenManagerStub(api.ScreenManager):
         self._activities.append(activity)
 
     def pop_activity(self) -> None:
+        if self._dialog is not None:
+            # If dialog is open, close it
+            self._dialog = None
+            return
+
         self._activities.pop()
 
     def push_modal(self, activity: api.Activity, options: api.ModalOptions) -> None:
@@ -131,6 +130,9 @@ class ScreenManagerStub(api.ScreenManager):
         task.add_done_callback(self._task_done)
         return task
 
+    def set_status(self, text: api.UrwidText) -> None:
+        self._status = text
+
     def _task_done(self, task: asyncio.Task) -> None:
         if task.cancelled():
             return
@@ -160,6 +162,9 @@ class ScreenManagerStub(api.ScreenManager):
     def stub_list_indicators(self) -> List[TopIndicatorStub]:
         return list(self._indicators.values())
 
+    def stub_get_status(self) -> Optional[api.UrwidText]:
+        return self._status
+
 
 class StoredSettingsStub(api.StoredSettings):
     _settings: Dict[str, Optional[api.JsonType]]
@@ -204,14 +209,72 @@ class OSPRocessStub(api.OSProcess):
         return self._returncode
 
 
+class MessageBusIntrospectionStub:
+    def __init__(self, bus_name: str, path: str) -> None:
+        self.bus_name = bus_name
+        self.path = path
+
+
+class MessageBusProxyObjectStub:
+    def __init__(
+        self,
+        bus_name: str,
+        path: str,
+        introspection: MessageBusIntrospectionStub,
+        impls: Dict[str, Any],
+    ) -> None:
+        self.__bus_name = bus_name
+        self.__path = path
+        self.__introspection = introspection
+        self.__impls = impls
+
+    def get_interface(self, name: str):
+        return self.__impls[name]
+        # return MessageBusProxyInterfaceStub(name, self.__impls[name])
+
+
+class MessageBusStub:
+    _impls: Dict[str, Dict[str, Any]]
+    _exported: Dict[str, Any]
+
+    def __init__(self) -> None:
+        self._impls = {}
+        self._exported = {}
+
+    async def introspect(
+        self, bus_name: str, path: str, timeout: float = 30.0
+    ) -> MessageBusIntrospectionStub:
+        return MessageBusIntrospectionStub(bus_name, path)
+
+    def get_proxy_object(
+        self, bus_name: str, path: str, introspection: MessageBusIntrospectionStub
+    ) -> MessageBusProxyObjectStub:
+        return MessageBusProxyObjectStub(
+            bus_name, path, introspection, self._impls.get(path, {})
+        )
+
+    def export(self, path: str, agent: Any) -> None:
+        self._exported[path] = agent
+
+    def stub_register_interface(self, path: str, iface_name: str, impl: Any) -> None:
+        ifaces = self._impls.setdefault(path, {})
+        ifaces[iface_name] = impl
+
+    def stub_get_exported(self) -> Dict[str, Any]:
+        return self._exported
+
+
 class OpenVarioOSStub(api.OpenVarioOS):
     _stub_run_returncode: int = 0
     _stub_run_stdout: bytes = b""
     _stub_run_stderr: bytes = b""
+    _stub_bus: Optional[MessageBusStub] = None
+    _stub_bus_connected: "asyncio.Future[MessageBusStub]"
 
     def __init__(self, log: List[str], rootfs: str) -> None:
         self._log = log
         self._rootfs = rootfs
+        self._stub_bus_connected = asyncio.Future()
 
     def mount_boot(self) -> None:
         self._log.append("OS: Mount /boot")
@@ -248,6 +311,19 @@ class OpenVarioOSStub(api.OpenVarioOS):
         self._stub_run_stdout = stdout
         self._stub_run_stderr = stderr
 
+    async def get_system_bus(self) -> BaseMessageBus:
+        return await self._stub_bus_connected
+
+    def stub_connect_bus(self) -> MessageBusStub:
+        self._stub_bus = MessageBusStub()
+        self._stub_bus_connected.set_result(self._stub_bus)
+        return self._stub_bus
+
+    def stub_fail_bus(self) -> None:
+        self._stub_bus_connected.set_exception(
+            api.DBusNotAvailableException("Stub connection failed")
+        )
+
 
 class NMEAStreamStub(api.NMEAStream):
     def __init__(self, nmeas: List[api.NMEA]) -> None:
