@@ -2,8 +2,7 @@ from typing import Optional
 
 import urwid
 
-from ovshell import api
-from ovshell import widget
+from ovshell import api, widget
 
 
 class AppRowItem(urwid.WidgetWrap):
