@@ -1,16 +1,15 @@
-from typing import Optional, Dict
-import os
 import asyncio
 import functools
+import os
+from typing import Dict, Optional
 
 import urwid
 
-from ovshell import api
-from ovshell import widget
+from ovshell import api, widget
 
-from .api import ProgressState, AutomountWatcher, Downloader, DownloadFilter, FileInfo
-from .usbcurtain import USBStorageCurtain, make_usbstick_watcher
+from .api import AutomountWatcher, Downloader, DownloadFilter, FileInfo, ProgressState
 from .downloader import DownloaderImpl
+from .usbcurtain import USBStorageCurtain, make_usbstick_watcher
 from .utils import format_size
 
 
@@ -145,7 +144,7 @@ class LogDownloaderActivity(api.Activity):
                 ("weight", 1, statusw),
             ]
         )
-        w = SelectableItem(cols)
+        w = widget.SelectableItem(cols)
 
         urwid.connect_signal(
             w, "click", self._file_clicked, user_args=[fileinfo, statusw]
@@ -184,20 +183,3 @@ class LogDownloaderActivity(api.Activity):
             return
 
         statusw.original_widget = urwid.Text(("success banner", " Done "))
-
-
-class SelectableItem(urwid.WidgetWrap):
-    signals = ["click"]
-
-    def __init__(self, widget: urwid.Widget) -> None:
-        wdg = urwid.AttrMap(widget, "li normal", "li focus")
-        super().__init__(wdg)
-
-    def selectable(self):
-        return True
-
-    def keypress(self, size, key: str) -> Optional[str]:
-        if self._command_map[key] == "activate":
-            self._emit("click")
-            return None
-        return key
